import { ProductSchema } from '@byondrnd/showroom-schemas';
import { TDefaultProducts, Visualizer } from '../../../Visualizer';
import { LayerDisplay } from './LayerDisplay';
import { IFavorite, IFavoriteScene, IApplication, IProduct } from '../../../EventSystem/EventTypes';
export declare class ProductsManager {
    visualizer: Visualizer;
    displayedProductsMap: Map<string, LayerDisplay>;
    favoriteProducts: Array<IFavorite>;
    favoriteSets: Array<IFavoriteScene>;
    private userDisplayedProducts;
    cart: string[];
    constructor(visualizer: Visualizer);
    setFavoriteSets(input: unknown): any;
    setFavoriteProducts(input: any): any;
    getUserDisplayedProducts(): TDefaultProducts;
    addUserDisplayedProduct(productSku: string, application: string): Promise<void>;
    displayProduct(productSku: string, application: string): Promise<void>;
    unDisplayAll(): void;
    unDisplayProduct(product: ProductSchema.IProduct): void;
    addProductToCart(sku: string): void;
    removeProductFromCart(sku: string): void;
    getFavoriteProducts(): Array<IFavorite>;
    addProductToFavorites(productSku: string, application: string): {
        name?: string;
        sku?: string;
        title?: string;
        description?: string;
        application?: string;
        image?: string;
        price?: string;
        facets?: {
            options?: any;
            name?: string;
        }[];
        _id?: string;
    };
    removeProductFromFavorites(productSku: string, application: string): {
        name?: string;
        sku?: string;
        title?: string;
        description?: string;
        application?: string;
        image?: string;
        price?: string;
        facets?: {
            options?: any;
            name?: string;
        }[];
        _id?: string;
    };
    getFavoriteSets(): IFavoriteScene[];
    addFavoriteScene(sceneId: string): Promise<{
        image?: string;
        id?: string;
        favorites?: {
            product?: {
                name?: string;
                sku?: string;
                title?: string;
                description?: string;
                application?: string;
                image?: string;
                price?: string;
                facets?: {
                    options?: any;
                    name?: string;
                }[];
                _id?: string;
            };
        }[];
        scene?: {
            name?: string;
            title?: string;
            experienceId?: string;
            sceneId?: string;
            previewImage?: string;
            subSelection?: {
                name?: string;
                title?: string;
                previewImage?: string;
            };
            subtitle?: string;
        };
    }>;
    removeFavoriteScene(setId: string): {
        image?: string;
        id?: string;
        favorites?: {
            product?: {
                name?: string;
                sku?: string;
                title?: string;
                description?: string;
                application?: string;
                image?: string;
                price?: string;
                facets?: {
                    options?: any;
                    name?: string;
                }[];
                _id?: string;
            };
        }[];
        scene?: {
            name?: string;
            title?: string;
            experienceId?: string;
            sceneId?: string;
            previewImage?: string;
            subSelection?: {
                name?: string;
                title?: string;
                previewImage?: string;
            };
            subtitle?: string;
        };
    };
    getDisplayedProduct(application: IApplication): IProduct;
    getDisplayedFormatedProduct(): Array<IProduct>;
    getApplicationLayerDisplay(application: string, renderOrder: number): Promise<LayerDisplay>;
    getDisplayedProducts(): Array<ProductSchema.IProduct>;
}
