import { TypedEmitter } from 'tiny-typed-emitter';
import { Utils, AppManager, Elements } from '@byondrnd/byond-web-lib';
import { CatalogManager } from './Managers/CatalogManager';
import { ProductsManager } from './Managers/Scene/ProductsManager/ProductsManager';
import { IEventSystem, EventSystemEventSignature, EventSystemEventDataSignature, IConfigurationFilter, IProduct, IApplication, VisualizerElement, IVisualizer, IScene, ISceneConfigurationEntityOutput } from './EventSystem/EventTypes';
import { SceneMetadataManager } from './Managers/Scene/SceneMetadataManager';
import { ImageOptimizeService } from '../utils/ImageOptimizeService';
declare type TProgress = {
    percent?: number;
};
declare type THotspotPoint = {
    application: string;
    title: string;
    elm: Elements.Screens.ScreenImage;
};
export declare type TDefaultProducts = Record<string, string>;
export declare class Visualizer extends TypedEmitter<IEventSystem> implements IVisualizer {
    appManager: AppManager;
    sceneSelector: string;
    mainContainerElement: VisualizerElement;
    sceneId?: string;
    sceneConfigurationLabel?: string;
    catalogManager: CatalogManager;
    productsManager: ProductsManager;
    sceneMetadataManager: SceneMetadataManager;
    debug: boolean;
    pubs: Utils.RxUtils.Subscription[];
    initAndLoaded: boolean;
    defaultProducts?: TDefaultProducts;
    defaultProduct?: string;
    maxFaceSize: number | null;
    maxFaceSizeMobile: number | null;
    experienceId?: string;
    experienceHash?: string;
    hotspots: THotspotPoint[];
    divs: HTMLDivElement[];
    divFirstGo: boolean[];
    ImageOptimizeService: ImageOptimizeService;
    imageOptimizerUrl: string;
    visualizerLoaded: undefined | {
        visualizer: Visualizer;
        experienceConfiguration: ISceneConfigurationEntityOutput;
    };
    sceneLoading: undefined | {
        scene: IScene;
        sceneConfiguration: ISceneConfigurationEntityOutput;
    };
    defaultApplication: string;
    constructor(containerSelector: string, sceneSelector: string);
    initAndLoad(): Promise<void>;
    setScene(sceneId: string, preventDefaultProducts?: boolean, preventEvent?: boolean, defaultApplication?: string): Promise<void>;
    emitRender(): void;
    setFavoriteScenes(favoriteScenes: any): void;
    setFavoriteProducts(favoriteProducts: any): void;
    private onZoneLoaded;
    private initCatalog;
    initialProductDisplay(params?: {
        defaultProduct?: string;
        defaultProducts?: TDefaultProducts;
    }): Promise<void>;
    savedUserProductsDisplay(userSetProducts: TDefaultProducts): Promise<void>;
    setSceneConfigurationLabel({ sceneConfigurationLabel, sceneId, productsList, defaultApplication, }: {
        sceneConfigurationLabel?: string;
        sceneId?: string;
        productsList?: string[];
        defaultApplication?: string;
    }): Promise<void>;
    getCurrentSceneConfiguration(): ISceneConfigurationEntityOutput;
    private subEventsAnalytics;
    private emitEventsAnalytics;
    getCurrentCatalogFieldsMap: () => import("./EventSystem/EventTypes").ICatalogFieldsMapping;
    getCurrentApplication(): IApplication;
    setCurrentApplication(application: IApplication | string, evenIfInView?: boolean): Promise<IApplication>;
    getFilters(): {
        options?: any;
        name?: string;
        customFieldName?: string;
        operator?: "not";
    }[];
    getCurrentFilters(): {
        options?: any;
        name?: string;
        customFieldName?: string;
        operator?: "not";
    }[];
    setFilter(filters: IConfigurationFilter[]): {
        options?: any;
        name?: string;
        customFieldName?: string;
        operator?: "not";
    }[];
    getDisplayedProduct(application: IApplication): {
        name?: string;
        sku?: string;
        title?: string;
        description?: string;
        application?: string;
        image?: string;
        price?: string;
        facets?: {
            options?: any;
            name?: string;
        }[];
        _id?: string;
    };
    getDisplayedProducts(): {
        name?: string;
        sku?: string;
        title?: string;
        description?: string;
        application?: string;
        image?: string;
        price?: string;
        facets?: {
            options?: any;
            name?: string;
        }[];
        _id?: string;
    }[];
    getProductList(): {
        name?: string;
        sku?: string;
        title?: string;
        description?: string;
        application?: string;
        image?: string;
        price?: string;
        facets?: {
            options?: any;
            name?: string;
        }[];
        _id?: string;
    }[];
    getApplicationsList(): IApplication[];
    addProductToFavorites(productSku: string, application: string): {
        product?: {
            name?: string;
            sku?: string;
            title?: string;
            description?: string;
            application?: string;
            image?: string;
            price?: string;
            facets?: {
                options?: any;
                name?: string;
            }[];
            _id?: string;
        };
    }[];
    removeProductFromFavorites(productSku: string, application: string): {
        product?: {
            name?: string;
            sku?: string;
            title?: string;
            description?: string;
            application?: string;
            image?: string;
            price?: string;
            facets?: {
                options?: any;
                name?: string;
            }[];
            _id?: string;
        };
    }[];
    getFavoriteProducts(): {
        product?: {
            name?: string;
            sku?: string;
            title?: string;
            description?: string;
            application?: string;
            image?: string;
            price?: string;
            facets?: {
                options?: any;
                name?: string;
            }[];
            _id?: string;
        };
    }[];
    addFavoriteScene(): Promise<{
        image?: string;
        id?: string;
        favorites?: {
            product?: {
                name?: string;
                sku?: string;
                title?: string;
                description?: string;
                application?: string;
                image?: string;
                price?: string;
                facets?: {
                    options?: any;
                    name?: string;
                }[];
                _id?: string;
            };
        }[];
        scene?: {
            name?: string;
            title?: string;
            experienceId?: string;
            sceneId?: string;
            previewImage?: string;
            subSelection?: {
                name?: string;
                title?: string;
                previewImage?: string;
            };
            subtitle?: string;
        };
    }[]>;
    removeFavoriteScene(setId: string): {
        image?: string;
        id?: string;
        favorites?: {
            product?: {
                name?: string;
                sku?: string;
                title?: string;
                description?: string;
                application?: string;
                image?: string;
                price?: string;
                facets?: {
                    options?: any;
                    name?: string;
                }[];
                _id?: string;
            };
        }[];
        scene?: {
            name?: string;
            title?: string;
            experienceId?: string;
            sceneId?: string;
            previewImage?: string;
            subSelection?: {
                name?: string;
                title?: string;
                previewImage?: string;
            };
            subtitle?: string;
        };
    }[];
    getFavoriteScenes(): {
        image?: string;
        id?: string;
        favorites?: {
            product?: {
                name?: string;
                sku?: string;
                title?: string;
                description?: string;
                application?: string;
                image?: string;
                price?: string;
                facets?: {
                    options?: any;
                    name?: string;
                }[];
                _id?: string;
            };
        }[];
        scene?: {
            name?: string;
            title?: string;
            experienceId?: string;
            sceneId?: string;
            previewImage?: string;
            subSelection?: {
                name?: string;
                title?: string;
                previewImage?: string;
            };
            subtitle?: string;
        };
    }[];
    getSceneList(): {
        name?: string;
        title?: string;
        experienceId?: string;
        sceneId?: string;
        previewImage?: string;
        subSelection?: {
            name?: string;
            title?: string;
            previewImage?: string;
        };
        subtitle?: string;
    }[];
    addProductToCart(product: IProduct): void;
    orderSample(product: IProduct): void;
    getCurrentSceneImage(): Promise<string>;
    getCurrentScene(): {
        name?: string;
        title?: string;
        experienceId?: string;
        sceneId?: string;
        previewImage?: string;
        subSelection?: {
            name?: string;
            title?: string;
            previewImage?: string;
        };
        subtitle?: string;
    };
    processId: string;
    emitAsyncOperationProgress: (progress?: TProgress) => boolean;
    displayProduct(productSku: string, application: IApplication, animateToProduct?: boolean): Promise<void>;
    displaySceneFromFavorites(id: string): Promise<void>;
    fetchMetadata(): Promise<string>;
    rotateCameraToApplication({ application, evenIfInView }: {
        application: string;
        evenIfInView?: boolean;
    }): Promise<void>;
    private initExperience;
    THREEBox: any;
    isObjectVisible: any;
    private isScreenElementVisible;
    emitRenderEvent(): void;
    private toScreenPosition;
    private unRegisterEvents;
    private registerEvents;
    private navigate;
    private loadProps;
    emit(eventName: EventSystemEventSignature, ...args: EventSystemEventDataSignature): boolean;
}
export {};
